[Ocfs2-devel] [PATCH 29/56] ocfs2: Use BH_JBDPrivateStart instead of BH_Unshadow

Mark Fasheh mfasheh at suse.com
Mon Dec 22 13:48:10 PST 2008


This is safer. We no longer have to worry about tracking changes to
jbd_state_bits.

Signed-off-by: Mark Fasheh <mfasheh at suse.com>
---
 fs/ocfs2/buffer_head_io.c |    5 ++---
 1 files changed, 2 insertions(+), 3 deletions(-)

diff --git a/fs/ocfs2/buffer_head_io.c b/fs/ocfs2/buffer_head_io.c
index 0e9eed0..15c8e6d 100644
--- a/fs/ocfs2/buffer_head_io.c
+++ b/fs/ocfs2/buffer_head_io.c
@@ -42,11 +42,10 @@
 /*
  * Bits on bh->b_state used by ocfs2.
  *
  * These MUST be after the JBD2 bits.  Currently BH_Unshadow is the last
  * JBD2 bit.
  */
 enum ocfs2_state_bits {
-	BH_NeedsValidate = BH_Unshadow + 1,
+	BH_NeedsValidate = BH_JBDPrivateStart,
 };
 
 /* Expand the magic b_state functions */
@@ -42,11 +42,10 @@
  * Bits on bh->b_state used by ocfs2.
  *
- * These MUST be after the JBD2 bits.  Currently BH_Unshadow is the last
- * JBD2 bit.
+ * These MUST be after the JBD2 bits.  Hence, we use BH_JBDPrivateStart.
  */
 enum ocfs2_state_bits {
-- 
1.5.6




More information about the Ocfs2-devel mailing list